Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1408)

Unified Diff: content/browser/service_worker/service_worker_dispatcher_host.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_dispatcher_host.cc
diff --git a/content/browser/service_worker/service_worker_dispatcher_host.cc b/content/browser/service_worker/service_worker_dispatcher_host.cc
index 4f626f6c7fcfbe2b286180fc0a5bf23995a9d7d6..3e2500dd4ee7c4bd15dfd70d9e4d8405699006f2 100644
--- a/content/browser/service_worker/service_worker_dispatcher_host.cc
+++ b/content/browser/service_worker/service_worker_dispatcher_host.cc
@@ -1039,8 +1039,8 @@ void ServiceWorkerDispatcherHost::
event->message_ports = MessagePort::ReleaseHandles(sent_message_ports);
event->source = source;
- // Hide the client url if the client has a unique origin.
- if (source_origin.unique()) {
+ // Hide the client url if the client has an opaque origin.
+ if (source_origin.opaque()) {
if (event->source.client_info.IsValid())
event->source.client_info.url = GURL();
else
« no previous file with comments | « content/browser/service_worker/service_worker_database.cc ('k') | content/browser/service_worker/service_worker_version.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698